Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TSAgent ¶
Wrapper type so we can add methods to the server.
func (*TSAgent) DispatchHostInfo ¶
Dispatches ALL the HostInfo entries in our Tailnet to the master
func (*TSAgent) GetStatusForPeer ¶
func (s *TSAgent) GetStatusForPeer(id string) (*tailcfg.HostinfoView, error)
Returns the raw hostinfo for a peer based on node ID.
Click to show internal directories.
Click to hide internal directories.